==> cronapp-framework-java-0.0.49-sources.jar: cronapp/framework/rest/ChangePassword.java <==
package cronapp.framework.rest;

import cronapi.Var;
import cronapi.database.DatabaseQueryManager;
import cronapp.framework.api.EventsManager;
import cronapp.framework.i18n.Messages;
import org.springframework.http.HttpStatus;
import org.springframework.security.authentication.BadCredentialsException;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.core.userdetails.User;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.RestController;

import cronapp.framework.api.ApiManager;

/**
 * Controller responsável por gerir a troca de
 * senha do usuário através de serviço REST
 *
 * @author Techne
 */
@RestController
@RequestMapping(value = "/changePassword")
public class ChangePassword {

  private final PasswordEncoder passwordEncoder = new BCryptPasswordEncoder();

  @SuppressWarnings("unchecked")
  @ResponseStatus(HttpStatus.OK)
  @RequestMapping(method = RequestMethod.POST)
  public void post(String oldPassword, String newPassword, String newPasswordConfirmation) throws Exception {
    if(!newPassword.equals(newPasswordConfirmation))
      throw new RuntimeException(Messages.getString("WrongConfirmationPassword"));

    User userDetails = (User)SecurityContextHolder.getContext().getAuthentication().getPrincipal();

    if (EventsManager.hasEvent("onChangePassword")) {
      EventsManager.executeEventOnTransaction("onChangePassword", Var.valueOf(userDetails.getUsername()), Var.valueOf(oldPassword), Var.valueOf(newPassword), Var.valueOf(newPasswordConfirmation));
    } else {
      ApiManager apiManager = ApiManager.byUser(userDetails.getUsername());
      cronapp.framework.api.User user = apiManager.getUser();
      if (user == null) {
        throw new UsernameNotFoundException(Messages.getString("UserNotFound"));
      } else {
        String password = user.getPassword();
        if (apiManager.passwordMatches(oldPassword, password)) {
          String passwordEncoded = passwordEncoder.encode(newPassword);
          apiManager.updatePassword(passwordEncoded);
        } else {
          throw new BadCredentialsException(Messages.getString("UserOrPassordInvalids"));
        }
      }
    }
  }
}

==> cronapp-framework-java-2.3.1-sources.jar: cronapp/framework/rest/ChangePassword.java <==
package cronapp.framework.rest;

import cronapi.AppConfig;
import cronapi.Var;
import cronapp.framework.CannotChangePasswordException;
import cronapp.framework.api.ApiManager;
import cronapp.framework.api.EventsManager;
import cronapp.framework.i18n.Messages;
import org.springframework.http.HttpStatus;
import org.springframework.security.authentication.BadCredentialsException;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.core.userdetails.User;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.RestController;

/**
 * Controller responsável por gerir a troca de
 * senha do usuário através de serviço REST
 *
 * @author Techne
 */
@RestController
@RequestMapping(value = "/changePassword")
public class ChangePassword {

  private final PasswordEncoder passwordEncoder = new BCryptPasswordEncoder();

  @SuppressWarnings("unchecked")
  @ResponseStatus(HttpStatus.OK)
  @RequestMapping(method = RequestMethod.POST)
  public void post(String oldPassword, String newPassword, String newPasswordConfirmation) throws Exception {
    String authenticationType = AppConfig.type();

    if (authenticationType != null && !authenticationType.equals("internal")) {
      throw new CannotChangePasswordException(Messages.getString("CannotChangePassword"));
    }

    if(!newPassword.equals(newPasswordConfirmation)) {
      throw new RuntimeException(Messages.getString("WrongConfirmationPassword"));
    }

    User userDetails = (User)SecurityContextHolder.getContext().getAuthentication().getPrincipal();

    if (EventsManager.hasEvent("onChangePassword")) {
      EventsManager.executeEventOnTransaction("onChangePassword", Var.valueOf(userDetails.getUsername()), Var.valueOf(oldPassword), Var.valueOf(newPassword), Var.valueOf(newPasswordConfirmation));
    } else {
      ApiManager apiManager = ApiManager.byUser(userDetails.getUsername());
      cronapp.framework.api.User user = apiManager.getUser();
      if (user == null) {
        throw new UsernameNotFoundException(Messages.getString("UserNotFound"));
      } else {
        String password = user.getPassword();
        if (apiManager.passwordMatches(oldPassword, password)) {
          String passwordEncoded = passwordEncoder.encode(newPassword);
          apiManager.updatePassword(passwordEncoded);
        } else {
          throw new BadCredentialsException(Messages.getString("UserOrPassordInvalids"));
        }
      }
    }
  }
}
